@@ -17,7 +17,7 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '2.2.17'
+__version__ = '2.2.20'
 __author__ = 'Celia Oakley'
 __copyright__ = 'Copyright (c) 2013-2020 Celia Oakley'
 __license__ = 'GPLv3'
@@ -29,7 +29,7 @@ from .base import APIKeyError
 from .changes import Changes
 from .configuration import Configuration, Certifications, Timezones
 from .discover import Discover
-from .find import Find
+from .find import Find, Trending
 from .genres import Genres
 from .movies import Movies, Collections, Companies, Keywords, Reviews
 from .people import People, Credits, Jobs
